.. image:: https://img.shields.io/pypi/v/igdiscover.svg?branch=master
    :target: https://pypi.python.org/pypi/igdiscover

.. image:: https://travis-ci.org/NBISweden/IgDiscover.svg?branch=master
    :target: https://travis-ci.org/NBISweden/IgDiscover

.. image:: https://img.shields.io/badge/install%20with-bioconda-brightgreen.svg
    :target: http://bioconda.github.io/recipes/igdiscover/README.html


==========
IgDiscover
==========

IgDiscover analyzes antibody repertoires and discovers new V genes from high-throughput sequencing reads.
Heavy chains, kappa and lambda light chains are supported (to discover VH, VK and VL genes).

IgDiscover is the result of a collaboration between the `Gunilla Karlsson Hedestam group <http://ki.se/en/mtc/gunilla-karlsson-hedestam-group>`_
at the `Department of Microbiology, Tumor and Cell Biology <http://ki.se/en/mtc/>`_ at `Karolinska Institutet <http://ki.se/en/>`_,
Sweden and the `Bioinformatics Long-Term Support <https://www.scilifelab.se/facilities/wabi/>`_ facility
at `Science for Life Laboratory (SciLifeLab) <https://www.scilifelab.se/>`_, Sweden.

If you use IgDiscover, please cite:

    | Corcoran, Martin M. and Phad, Ganesh E. and Bernat, Néstor Vázquez and Stahl-Hennig,
      Christiane and Sumida, Noriyuki and Persson, Mats A.A. and Martin, Marcel and
      Karlsson Hedestam, Gunilla B.
    | *Production of individualized V gene databases reveals high levels of immunoglobulin genetic
      diversity.*
    | Nature Communications 7:13642 (2016)
    | https://dx.doi.org/10.1038/ncomms13642


Links
-----

* `Documentation <http://docs.igdiscover.se/>`_
* `Source code <https://github.com/NBISweden/IgDiscover/>`_
* `Report an issue <https://github.com/NBISweden/IgDiscover/issues>`_
* `Project page on PyPI (Python package index) <https://pypi.python.org/pypi/igdiscover/>`_

|

.. figure:: https://raw.githubusercontent.com/NBISweden/IgDiscover/master/doc/clusterplot.jpeg

|

